==> haskell-foldable1-classes-compat-0.1-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldable1-classes-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foldable1-classes-compat
version:              0.1
visibility:           public
id:                   foldable1-classes-compat-0.1-CZAZNq3qNPg81g9IQ991tn
key:                  foldable1-classes-compat-0.1-CZAZNq3qNPg81g9IQ991tn
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Edward Kmett, Oleg Grenrus
homepage:             https://github.com/haskell-compat/foldable1-classes-compat
synopsis:
    Compatibility package for the Foldable1 and Bifoldable1 type classes

description:
    A compatibility package for the @Foldable1@ and @Bifoldable1@ type classes,
    which were introduced in @base-4.18.0.0@ (GHC 9.6.1). For more information,
    see <https://github.com/haskell/core-libraries-committee/issues/9 this Core
    Libraries Committee proposal>.

    @Foldable1@ and @Bifoldable1@ classify non-empty data structures that can be
    folded to a summary value.

category:             Data, Compatibility
abi:                  86ac4c646a23e41f6e2f5f4c9e9d737d
exposed:              True
exposed-modules:      Data.Bifoldable1 Data.Foldable1
import-dirs:          /usr/lib/ghc-9.2.8/site-local/foldable1-classes-compat-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/foldable1-classes-compat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldable1-classes-compat
hs-libraries:         HSfoldable1-classes-compat-0.1-CZAZNq3qNPg81g9IQ991tn
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-prim-0.8.0
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-foldable1-classes-compat/html/foldable1-classes-compat.haddock

haddock-html:         /usr/share/doc/haskell-foldable1-classes-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldable1-classes-compat-0.1-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldable1-classes-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foldable1-classes-compat
version:              0.1
visibility:           public
id:                   foldable1-classes-compat-0.1-2aUHZ5vTLgZAu86m2dUcRb
key:                  foldable1-classes-compat-0.1-2aUHZ5vTLgZAu86m2dUcRb
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Edward Kmett, Oleg Grenrus
homepage:             https://github.com/haskell-compat/foldable1-classes-compat
synopsis:
    Compatibility package for the Foldable1 and Bifoldable1 type classes

description:
    A compatibility package for the @Foldable1@ and @Bifoldable1@ type classes,
    which were introduced in @base-4.18.0.0@ (GHC 9.6.1). For more information,
    see <https://github.com/haskell/core-libraries-committee/issues/9 this Core
    Libraries Committee proposal>.

    @Foldable1@ and @Bifoldable1@ classify non-empty data structures that can be
    folded to a summary value.

category:             Data, Compatibility
abi:                  bab57ff4973c5334818ff3e2a56d97a5
exposed:              True
exposed-modules:      Data.Bifoldable1 Data.Foldable1
import-dirs:          /usr/lib/ghc-9.2.8/site-local/foldable1-classes-compat-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/foldable1-classes-compat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldable1-classes-compat
hs-libraries:         HSfoldable1-classes-compat-0.1-2aUHZ5vTLgZAu86m2dUcRb
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-prim-0.8.0
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-foldable1-classes-compat/html/foldable1-classes-compat.haddock

haddock-html:         /usr/share/doc/haskell-foldable1-classes-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
